@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import logging
 from copy import deepcopy
 from typing import TYPE_CHECKING, Tuple, List, Any, Dict, Optional
@@ -430,7 +432,6 @@ class CloudformationVariableRenderer(VariableRenderer):
                 except KeyError:
                     logging.info(f'Failed to evalue cfn function. val_to_eval: {val_to_eval}')
 
-
                 if evaluated_value and evaluated_value != original_value:
                     # succeeded to evaluate an edge
                     val_to_eval[cfn_evaluation_function] = evaluated_value
@@ -456,7 +457,14 @@ class CloudformationVariableRenderer(VariableRenderer):
                         attribute_at_dest=evaluated_value['attribute_at_dest']
                     )
 
-    def _evaluate_cfn_function(self, edge, origin_vertex, cfn_evaluation_function, val_to_eval, dest_vertex_attributes):
+    def _evaluate_cfn_function(
+        self,
+        edge: Edge,
+        origin_vertex: Block,
+        cfn_evaluation_function: str,
+        val_to_eval: dict[str, Any],
+        dest_vertex_attributes: dict[str, Any],
+    ) -> tuple[str | None, int | None, str | None]:
         (evaluated_value, changed_origin_id, attribute_at_dest) = (None, None, None)
 
         if cfn_evaluation_function == ConditionFunctions.IF:
