@@ -3,29 +3,33 @@ from __future__ import annotations
 import logging
 import re
 from itertools import groupby
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Pattern, Any
+
+from checkov.common.bridgecrew.check_type import CheckType
 
 from checkov.common.bridgecrew.integration_features.base_integration_feature import BaseIntegrationFeature
 from checkov.common.bridgecrew.integration_features.features.policy_metadata_integration import \
     integration as metadata_integration
 from checkov.common.bridgecrew.platform_integration import bc_integration
 from checkov.common.models.enums import CheckResult
+from checkov.common.output.record import SCA_PACKAGE_SCAN_CHECK_NAME
 
 if TYPE_CHECKING:
+    from checkov.common.bridgecrew.platform_integration import BcPlatformIntegration
     from checkov.common.output.report import Report
+    from checkov.common.output.record import Record
 
 
 class SuppressionsIntegration(BaseIntegrationFeature):
-
-    def __init__(self, bc_integration):
-        super().__init__(bc_integration, order=1)  # must be after the policy metadata
-        self.suppressions = {}
+    def __init__(self, bc_integration: BcPlatformIntegration) -> None:
+        super().__init__(bc_integration=bc_integration, order=1)  # must be after the policy metadata
+        self.suppressions: dict[str, list[dict[str, Any]]] = {}
         self.suppressions_url = f"{self.bc_integration.api_url}/api/v1/suppressions"
 
         # bcorgname_provider_timestamp (ex: companyxyz_aws_1234567891011)
         # the provider may be lower or upper depending on where the policy was created
         self.custom_policy_id_regex = re.compile(r'^[a-zA-Z0-9]+_[a-zA-Z]+_\d{13}$')
-        self.repo_name_regex = None
+        self.repo_name_regex: Pattern[str] | None = None
 
     def is_valid(self) -> bool:
         return (
@@ -69,6 +73,13 @@ class SuppressionsIntegration(BaseIntegrationFeature):
         still_failed_checks = []
         still_passed_checks = []
         for check in scan_report.failed_checks + scan_report.passed_checks:
+            # in order to be able to suppress by policy we assign the relevant check id for package / image scan
+            # and avoiding licenses vulns
+            if scan_report.check_type == CheckType.SCA_PACKAGE and check.check_name == SCA_PACKAGE_SCAN_CHECK_NAME:
+                check.check_id = 'BC_VUL_2'
+            if scan_report.check_type == CheckType.SCA_IMAGE and check.check_name == SCA_PACKAGE_SCAN_CHECK_NAME:
+                check.check_id = 'BC_VUL_1'
+
             relevant_suppressions = self.suppressions.get(check.check_id)
 
             applied_suppression = self._check_suppressions(check, relevant_suppressions) if relevant_suppressions else None
@@ -86,7 +97,7 @@ class SuppressionsIntegration(BaseIntegrationFeature):
         scan_report.failed_checks = still_failed_checks
         scan_report.passed_checks = still_passed_checks
 
-    def _check_suppressions(self, record, suppressions):
+    def _check_suppressions(self, record: Record, suppressions: list[dict[str, Any]]) -> dict[str, Any] | None:
         """
         Checks the specified suppressions against the specified record, returning the first applicable suppression,
         or None of no suppression is applicable.
@@ -99,7 +110,7 @@ class SuppressionsIntegration(BaseIntegrationFeature):
                 return suppression
         return None
 
-    def _check_suppression(self, record, suppression):
+    def _check_suppression(self, record: Record, suppression: dict[str, Any]) -> bool:
         """
         Returns True if and only if the specified suppression applies to the specified record.
         :param record:
@@ -136,9 +147,15 @@ class SuppressionsIntegration(BaseIntegrationFeature):
                 if entity_tags.get(key) == value:
                     return True
 
+        elif type == 'CvesAccounts':
+            if self.bc_integration.repo_id in suppression['accountIds']:
+                if record.vulnerability_details and record.vulnerability_details['id'] in suppression['cves']:
+                    return True
+            return False
+
         return False
 
-    def _suppression_valid_for_run(self, suppression):
+    def _suppression_valid_for_run(self, suppression: dict[str, Any]) -> bool:
         """
         Returns whether this suppression is valid. A suppression is NOT valid if:
         - the policy does not have a checkov ID and does not have an ID matching a custom policy format
@@ -157,11 +174,15 @@ class SuppressionsIntegration(BaseIntegrationFeature):
 
         return True
 
-    def _repo_matches(self, repo_name):
+    def _repo_matches(self, repo_name: str) -> bool:
+        if not self.repo_name_regex:
+            # shouldn't happen
+            return False
+
         # matches xyz_org/repo or org/repo (where xyz is the BC org name and the CLI repo prefix from the platform)
         return self.repo_name_regex.match(repo_name) is not None
 
-    def _init_repo_regex(self):
+    def _init_repo_regex(self) -> None:
         self.repo_name_regex = re.compile(f'^([a-zA-Z0-9]+_)?{self.bc_integration.repo_id}$')
 
 
