@@ -19,6 +19,7 @@ class BcSeverities:
     CRITICAL = 'CRITICAL'
     MODERATE = 'MODERATE'
     IMPORTANT = 'IMPORTANT'
+    OFF = 'OFF'
 
 
 Severities = {
@@ -29,6 +30,7 @@ Severities = {
     BcSeverities.HIGH: Severity(BcSeverities.HIGH, 3),
     BcSeverities.IMPORTANT: Severity(BcSeverities.HIGH, 3),
     BcSeverities.CRITICAL: Severity(BcSeverities.CRITICAL, 4),
+    BcSeverities.OFF: Severity(BcSeverities.OFF, 999),
 }
 
 
