@@ -48,3 +48,14 @@ class SafeLineLoader(SafeLoader):
         mapping['__startline__'] = node.start_mark.line + 1
         mapping['__endline__'] = node.end_mark.line + 1
         return mapping
+
+    bool_values = {  # noqa: CCE003  # used to override the SafeLoader default behaviour
+        'yes': True,
+        'no': False,
+        'true': True,
+        'false': False,
+        # GHA workflow files have a saved word for "on". Since we have policies inspecting the "on" section we need
+        # to keep the string value.
+        'on': 'on',
+        'off': False,
+    }
