@@ -15,17 +15,23 @@ from typing import List, Dict, Any, Optional, cast, TYPE_CHECKING, TypeVar
 
 from typing_extensions import Literal
 
+from checkov.common.bridgecrew.code_categories import CodeCategoryMapping
 from checkov.common.bridgecrew.integration_features.features.policy_metadata_integration import \
     integration as metadata_integration
+from checkov.common.bridgecrew.integration_features.features.repo_config_integration import \
+    integration as repo_config_integration
 from checkov.common.bridgecrew.integration_features.integration_feature_registry import integration_feature_registry
+from checkov.common.bridgecrew.severities import Severities
 from checkov.common.images.image_referencer import ImageReferencer
 from checkov.common.output.csv import CSVSBOM
 from checkov.common.output.cyclonedx import CycloneDX
-from checkov.common.output.report import Report
+from checkov.common.output.report import Report, merge_reports
 from checkov.common.parallelizer.parallel_runner import parallel_runner
+from checkov.common.typing import _ExitCodeThresholds
 from checkov.common.util import data_structures_utils
 from checkov.common.util.banner import tool as tool_name
 from checkov.common.util.json_utils import CustomJSONEncoder
+from checkov.common.util.type_forcers import convert_csv_string_arg_to_list, force_list
 from checkov.sca_image.runner import Runner as image_runner
 from checkov.terraform.context_parsers.registry import parser_registry
 from checkov.terraform.parser import Parser
@@ -53,6 +59,7 @@ class RunnerRegistry:
         self.image_referencing_runners = self._get_image_referencing_runners()
         self.filter_runner_framework()
         self.tool = tool_name
+        self._check_type_to_report_map: dict[str, Report] = {}  # used for finding reports with the same check type
         for runner in runners:
             if isinstance(runner, image_runner):
                 runner.image_referencers = self.image_referencing_runners
@@ -83,10 +90,29 @@ class RunnerRegistry:
 
             reports = parallel_runner.run_function(func=_parallel_run, items=self.runners, group_size=1)
 
-        for scan_report in reports:
+        merged_reports = self._merge_reports(reports)
+
+        for scan_report in merged_reports:
             self._handle_report(scan_report, repo_root_for_plan_enrichment)
         return self.scan_reports
 
+    def _merge_reports(self, reports: Iterable[Report | list[Report]]) -> list[Report]:
+        """Merges reports with the same check_type"""
+
+        merged_reports = []
+
+        for report in reports:
+            sub_reports: list[Report] = force_list(report)
+            for sub_report in sub_reports:
+                if sub_report.check_type in self._check_type_to_report_map:
+                    merge_reports(self._check_type_to_report_map[sub_report.check_type], sub_report)
+                else:
+                    self._check_type_to_report_map[sub_report.check_type] = sub_report
+
+                merged_reports.append(sub_report)
+
+        return merged_reports
+
     def _handle_report(self, scan_report: Report, repo_root_for_plan_enrichment: list[str | Path] | None) -> None:
         integration_feature_registry.run_post_runner(scan_report)
         if metadata_integration.check_metadata:
@@ -106,6 +132,69 @@ class RunnerRegistry:
             logging.error(f"\nAn error occurred while writing {data_format} results to file: {file_name}",
                           exc_info=True)
 
+    @staticmethod
+    def get_fail_thresholds(config: argparse.Namespace, report_type: str) -> _ExitCodeThresholds:
+
+        soft_fail = config.soft_fail
+
+        soft_fail_on_checks = []
+        soft_fail_threshold = None
+        # soft fail on the highest severity threshold in the list
+        for val in convert_csv_string_arg_to_list(config.soft_fail_on):
+            if val.upper() in Severities:
+                val = val.upper()
+                if not soft_fail_threshold or Severities[val].level > soft_fail_threshold.level:
+                    soft_fail_threshold = Severities[val]
+            else:
+                soft_fail_on_checks.append(val)
+
+        logging.debug(f'Soft fail severity threshold: {soft_fail_threshold.level if soft_fail_threshold else None}')
+        logging.debug(f'Soft fail checks: {soft_fail_on_checks}')
+
+        hard_fail_on_checks = []
+        hard_fail_threshold = None
+        # hard fail on the lowest threshold in the list
+        for val in convert_csv_string_arg_to_list(config.hard_fail_on):
+            if val.upper() in Severities:
+                val = val.upper()
+                if not hard_fail_threshold or Severities[val].level < hard_fail_threshold.level:
+                    hard_fail_threshold = Severities[val]
+            else:
+                hard_fail_on_checks.append(val)
+
+        logging.debug(f'Hard fail severity threshold: {hard_fail_threshold.level if hard_fail_threshold else None}')
+        logging.debug(f'Hard fail checks: {hard_fail_on_checks}')
+
+        if not config.use_enforcement_rules:
+            logging.debug('Use enforcement rules is FALSE')
+        elif not soft_fail:
+            code_category_type = CodeCategoryMapping[report_type]
+            enf_rule = repo_config_integration.code_category_configs.get(code_category_type)
+
+            if enf_rule:
+                logging.debug('Use enforcement rules is TRUE')
+
+                # if there is a severity in either the soft-fail-on list or hard-fail-on list, then we will ignore enforcement rules
+                # if the lists only contain check IDs, then we will merge them with the enforcement rule value
+                if soft_fail_threshold or hard_fail_threshold:
+                    logging.debug('Soft or hard fail threshold is set; ignoring enforcement rules')
+                else:
+                    hard_fail_threshold = enf_rule.hard_fail_threshold
+                    soft_fail = enf_rule.is_global_soft_fail()
+                    logging.debug(f'Using enforcement rule hard fail threshold for this report: {hard_fail_threshold.name}')
+            else:
+                logging.debug(f'Use enforcement rules is TRUE, but did not find an enforcement rule for report type {report_type}, so falling back to CLI args')
+        else:
+            logging.debug('Soft fail was true; ignoring enforcement rules')
+
+        return {
+            'soft_fail': soft_fail,
+            'soft_fail_checks': soft_fail_on_checks,
+            'soft_fail_threshold': soft_fail_threshold,
+            'hard_fail_checks': hard_fail_on_checks,
+            'hard_fail_threshold': hard_fail_threshold
+        }
+
     def print_reports(
             self,
             scan_reports: List[Report],
@@ -145,10 +234,11 @@ class RunnerRegistry:
                     git_org = ""
                     git_repository = ""
                     if 'repo_id' in config and config.repo_id is not None:
-                        git_org,git_repository = config.repo_id.split('/')
+                        git_org, git_repository = config.repo_id.split('/')
                     csv_sbom_report.add_report(report=report, git_org=git_org, git_repository=git_repository)
             logging.debug(f'Getting exit code for report {report.check_type}')
-            exit_codes.append(report.get_exit_code(config.soft_fail, config.soft_fail_on, config.hard_fail_on))
+            exit_code_thresholds = self.get_fail_thresholds(config, report.check_type)
+            exit_codes.append(report.get_exit_code(exit_code_thresholds))
 
         if "cli" in config.output:
             cli_output = ''
@@ -252,10 +342,19 @@ class RunnerRegistry:
         exit_code = 1 if 1 in exit_codes else 0
         return cast(Literal[0, 1], exit_code)
 
-    def print_iac_bom_reports(self, output_path: str, scan_reports: list[Report], output_types: list[str]) -> None:
+    def print_iac_bom_reports(self, output_path: str,
+                              scan_reports: list[Report],
+                              output_types: list[str],
+                              account_id: str | None = None) -> dict[str, str]:
+
+        output_files = {
+            'cyclonedx': 'results_cyclonedx.xml',
+            'csv': 'results_iac.csv'
+        }
+
         # create cyclonedx report
         if 'cyclonedx' in output_types:
-            cyclonedx_output_path = 'results_cyclonedx.xml'
+            cyclonedx_output_path = output_files['cyclonedx']
             cyclonedx = CycloneDX(reports=scan_reports,
                                   repo_id=metadata_integration.bc_integration.repo_id,
                                   export_iac_only=True)
@@ -269,8 +368,11 @@ class RunnerRegistry:
             csv_sbom_report = CSVSBOM()
             for report in scan_reports:
                 if not report.is_empty():
-                    csv_sbom_report.add_report(report=report, git_org="", git_repository="")
-            csv_sbom_report.persist_report_iac(file_name='results_iac.csv', output_path=output_path)
+                    git_org, git_repository = self.extract_git_info_from_account_id(account_id)
+                    csv_sbom_report.add_report(report=report, git_org=git_org, git_repository=git_repository)
+            csv_sbom_report.persist_report_iac(file_name=output_files['csv'], output_path=output_path)
+
+        return {key: os.path.join(output_path, value) for key, value in output_files.items()}
 
     def filter_runner_framework(self) -> None:
         if not self.runner_filter:
@@ -354,7 +456,18 @@ class RunnerRegistry:
     def strip_code_blocks_from_json(report_jsons: List[Dict[str, Any]]) -> None:
         for report in report_jsons:
             results = report.get('results', {})
-            for key, result in results.items():
+            for result in results.values():
                 for result_dict in result:
-                    result_dict.pop('code_block', None)
-                    result_dict.pop('connected_node', None)
+                    result_dict["code_block"] = None
+                    result_dict["connected_node"] = None
+
+    @staticmethod
+    def extract_git_info_from_account_id(account_id: str | None) -> tuple[str, str]:
+        if account_id and '/' in account_id:
+            account_id_list = account_id.split('/')
+            git_org = '/'.join(account_id_list[0:-1])
+            git_repository = account_id_list[-1]
+        else:
+            git_org, git_repository = "", ""
+
+        return git_org, git_repository
