@@ -1,4 +1,5 @@
 import re
+from typing import Any, Tuple, Dict
 
 from checkov.common.models.enums import CheckResult
 from checkov.github_actions.checks.base_github_action_check import BaseGithubActionsCheck
@@ -14,10 +15,13 @@ class DontAllowShellInjection(BaseGithubActionsCheck):
             name=name,
             id=id,
             block_type=BlockType.ARRAY,
-            supported_entities=['jobs','jobs.*.steps[]']
+            supported_entities=('jobs', 'jobs.*.steps[]')
         )
 
-    def scan_entity_conf(self, conf):
+    def scan_entity_conf(self, conf: Dict[str, Any]) -> Tuple[CheckResult, Dict[str, Any]]:
+        if not isinstance(conf, dict):
+            return CheckResult.UNKNOWN, conf
+
         if "run" not in conf:
             return CheckResult.PASSED, conf
         run = conf.get("run", "")
